"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitlabService = void 0;
const lodash_1 = __importDefault(require("lodash"));
const gitlab_api_1 = require("./gitlab.api");
class GitlabService {
    constructor(inputs) {
        this.gitlabApi = new gitlab_api_1.GitlabApi(inputs);
    }
    async getPullRequestsWithCommits(repo, branch) {
        try {
            const prs = await this.gitlabApi.getPullRequests(repo, branch);
            return Promise.all(prs.map(async (pr) => {
                const info = await this.gitlabApi.getCommitsInfo(repo, pr);
                const result = {
                    ...info,
                    prDate: pr.closed_at || pr.updated_at,
                    number: pr.iid,
                    url: `${pr.web_url}`,
                    title: pr.title,
                };
                return result;
            }));
        }
        catch (error) {
            throw new Error(`failed to get pull requests: ${error.message}`);
        }
    }
    async getBranch(repo, branch) {
        try {
            const gitlabBranch = await this.gitlabApi.getBranch(repo, branch);
            return {
                name: gitlabBranch.name,
                commit: gitlabBranch.commit.id,
                commitMsg: gitlabBranch.commit.message,
                commitURL: gitlabBranch.commit.web_url || gitlabBranch.web_url,
                committerUsername: gitlabBranch.commit.committer_name
            };
        }
        catch (error) {
            if (lodash_1.default.get(error, 'response.statusCode') === 404) {
                return;
            }
            throw new Error(`failed to get branch: ${error.message}`);
        }
    }
}
exports.GitlabService = GitlabService;
//# sourceMappingURL=gitlab.service.js.map